#!/bin/bash
## Susumu Tanimura
## Time-stamp: <2014-06-27 17:36:15 umusus>
## Get headings and text from the JIAH international health dictionary

##### ここを書き換える ###########
export FPWLIBEXECDIR=/usr/share/freepwing
#################################

_DATA="ihd.dat"

usage() {
		echo Usage: $(basename $0)
}

getAllURL() {
		# 一覧から各用語のURLを取得
		_U1='http://seesaawiki.jp/w/jaih/l/?p=0&order=lastupdate&on_desc=1'
		_U2='http://seesaawiki.jp/w/jaih/l/?p=1&order=lastupdate&on_desc=1'
		_U3='http://seesaawiki.jp/w/jaih/l/?p=2&order=lastupdate&on_desc=1'
		
		if w3m -help 2>/dev/null 1>&2; then
				echo Now getting words list and URL from the JIAH international health dictionary ... 1>&2
				w3m -dump_source ${_U1} | grep -oE 'http://seesaawiki\.jp/w/jaih/d/[A-Za-z0-9%]*'
				w3m -dump_source ${_U2} | grep -oE 'http://seesaawiki\.jp/w/jaih/d/[A-Za-z0-9%]*'
				w3m -dump_source ${_U3} | grep -oE 'http://seesaawiki\.jp/w/jaih/d/[A-Za-z0-9%]*'
				exit 0
		else
				echo w3m was not found
				exit 1
		fi
}

sanitizeURL() {
		# 必要のないURLを削除
		getAllURL | grep -v Template | grep -v MenuBar | grep -v FrontPage
}

getHeadings() {
		# 用語見出しの取得
		w3m -dump $1 | sed -n '16,16p' | sed -e 's/編集する//g'
}

getContents() {
		# 用語の解説の取得
		w3m -dump $1 | sed -n '23,/このページを編集する/p' | head -n -2
}

## メイン処理
for url in $(sanitizeURL); do
		tmp=$(tempfile).html
		wget -O $tmp $url
		heading=$(getHeadings $tmp)
		if [ ! -z $heading ]; then
				echo "<heading>$(getHeadings $tmp)</heading>"
				getContents $tmp
		fi
		rm $tmp
done | nkf -Ie > $_DATA

if [ -d ./IH ]; then
 rm -rf ./IH
 echo 古い国際保健用語集電子辞書を削除しました
fi
make --include-dir="$FPWLIBEXECDIR" clean
[ $? -eq 0 ] && make --include-dir="$FPWLIBEXECDIR" | nkf -w
[ $? -eq 0 ] && fpwmake --include-dir="$FPWLIBEXECDIR" catalogs
[ $? -eq 0 ] && fpwmake --include-dir="$FPWLIBEXECDIR" install
[ $? -eq 0 ] && echo 新しい国際保健用語集電子辞書の作成が完了しました

